# Reference
<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

**Classes**

* [`freeipa`](#freeipa): Manages IPA masters, replicas and clients.
* [`freeipa::config::admin_user`](#freeipaconfigadmin_user): Configures admin user
* [`freeipa::config::webui`](#freeipaconfigwebui): Configures port and redirect overrides for the IPA server web UI.
* [`freeipa::install`](#freeipainstall): Installs the packages needed for servers and clients
* [`freeipa::install::autofs`](#freeipainstallautofs): Installs and start autofs
* [`freeipa::install::client`](#freeipainstallclient): Install freeipa client
* [`freeipa::install::server`](#freeipainstallserver): This class mainly defines options for the ipa install command, then install master or replica regarding the role set.
* [`freeipa::install::server::master`](#freeipainstallservermaster): Installs freeipa server as master
* [`freeipa::install::server::replica`](#freeipainstallserverreplica): Installs freeipa server as replica
* [`freeipa::install::sssd`](#freeipainstallsssd): Install sssd package

**Defined types**

* [`freeipa::helpers::flushcache`](#freeipahelpersflushcache): Flushcache sss for Debian and RedHat only

## Classes

### freeipa

Parameters
----------
Also, triggers the install of the required dns server packages.
and passed to the IPA installer.
and passed to the IPA installer.
requests whose HTTP_HOST variable match the parameter 'webio_proxy_external_fqdn'. This allows the IPA Web UI to work on a
proxied port, while allowing IPA client access to  function as normal.
the Web UI to be accessed from different ports and hostnames than the default.
This is necessary to allow the WebUI to be accessed behind a reverse proxy when using nonstandard ports.

#### Examples

##### 

```puppet
class {'freeipa':
    ipa_role                    => 'master',
    domain                      => 'example.lan',
    ipa_server_fqdn             => 'ipa-server-1.example.lan',
    admin_password              => 'vagrant123',
    directory_services_password => 'vagrant123',
    install_ipa_server          => true,
    ip_address                  => '10.10.10.35',
    enable_ip_address           => true,
    enable_hostname             => true,
    manage_host_entry           => true,
    install_epel                => true,
    webui_disable_kerberos      => true,
    webui_enable_proxy          => true,
    webui_force_https           => true,
}
```

#### Parameters

The following parameters are available in the `freeipa` class.

##### `domain`

Data type: `Stdlib::Fqdn`

The name of the IPA domain to create or join.

##### `ipa_role`

Data type: `Enum['master','replica','client']`

What role the node will be. Options are 'master', 'replica', and 'client'.

##### `admin_password`

Data type: `String[8]`

Password which will be assigned to the IPA account named 'admin'.

##### `directory_services_password`

Data type: `String[8]`

Password which will be passed into the ipa setup's parameter named "--ds-password".

##### `autofs_package_name`

Data type: `String`

Name of the autofs package to install if enabled.

Default value: 'autofs'

##### `client_install_ldaputils`

Data type: `Boolean`

If true, then the ldaputils packages are installed if ipa_role is set to client.

Default value: `false`

##### `configure_dns_server`

Data type: `Boolean`

If true, then the parameter '--setup-dns' is passed to the IPA server installer.

Default value: `true`

##### `configure_ntp`

Data type: `Boolean`

If false, then the parameter '--no-ntp' is passed to the IPA server installer.

Default value: `true`

##### `custom_dns_forwarders`

Data type: `Array[String]`

Each element in this array is prefixed with '--forwarder' and passed to the IPA server installer.

Default value: []

##### `principal_usedto_joindomain`

Data type: `String`

The principal (usually username) used to join a client or replica to the IPA domain.

Default value: 'admin'

##### `password_usedto_joindomain`

Data type: `String`

The password for the domain_join_principal.

Default value: $directory_services_password

##### `enable_hostname`

Data type: `Boolean`

If true, then the parameter '--hostname' is populated with the parameter 'ipa_server_fqdn'

Default value: `true`

##### `enable_ip_address`

Data type: `Boolean`

If true, then the parameter '--ip-address' is populated with the parameter 'ip_address'

Default value: `false`

##### `fixed_primary`

Data type: `Boolean`

If true, then the parameter '--fixed-primary' is passed to the IPA installer.

Default value: `false`

##### `idstart`

Data type: `Integer[10000]`

From the IPA man pages: "The starting user and group id number".

Default value: 10000

##### `install_autofs`

Data type: `Boolean`

If true, then the autofs packages are installed.

Default value: `false`

##### `install_epel`

Data type: `Boolean`

If true, then the epel repo is installed. The epel repo is usually required for sssd packages.

Default value: `true`

##### `install_kstart`

Data type: `Boolean`

If true, then the kstart packages are installed.

Default value: `true`

##### `install_sssdtools`

Data type: `Boolean`

If true, then the sssdtools packages are installed.

Default value: `true`

##### `ipa_client_package_name`

Data type: `String`

Name of the IPA client package.

Default value: $facts['os']['family']

##### `ipa_server_package_name`

Data type: `String`

Name of the IPA server package.

Default value: 'ipa-server'

##### `install_ipa_client`

Data type: `Boolean`

If true, then the IPA client packages are installed if the parameter 'ipa_role' is set to 'client'.

Default value: `true`

##### `install_ipa_server`

Data type: `Boolean`

If true, then the IPA server packages are installed if the parameter 'ipa_role' is not set to 'client'.

Default value: `true`

##### `install_sssd`

Data type: `Boolean`

If true, then the sssd packages are installed.

Default value: `true`

##### `ip_address`

Data type: `Stdlib::IP::Address`

IP address to pass to the IPA installer.

##### `ipa_server_fqdn`

Data type: `Stdlib::Fqdn`

Actual fqdn of the IPA server or client.

Default value: $facts['networking']['fqdn']

##### `kstart_package_name`

Data type: `String`

Name of the kstart package.

Default value: 'kstart'

##### `ldaputils_package_name`

Data type: `String`

Name of the ldaputils package.

Default value: $facts['os']['family']

##### `ipa_master_fqdn`

Data type: `Stdlib::Fqdn`

FQDN of the server to use for a client or replica domain join.

##### `manage_host_entry`

Data type: `Boolean`

If true, then a host entry is created using the parameters 'ipa_server_fqdn' and 'ip_address'.

Default value: `false`

##### `mkhomedir`

Data type: `Boolean`

If true, then the parameter '--mkhomedir' is passed to the IPA client installer.

Default value: `true`

##### `no_ui_redirect`

Data type: `Boolean`

If true, then the parameter '--no-ui-redirect' is passed to the IPA server installer.

Default value: `false`

##### `realm`

Data type: `Stdlib::Fqdn`

The name of the IPA realm to create or join.

Default value: upcase($domain)

##### `server_install_ldaputils`

Data type: `Boolean`

If true, then the ldaputils packages are installed if ipa_role is not set to client.

Default value: `true`

##### `sssd_package_name`

Data type: `String`

Name of the sssd package.

Default value: 'sssd-common'

##### `sssdtools_package_name`

Data type: `String`

Name of the sssdtools package.

Default value: 'sssd-tools'

##### `webui_disable_kerberos`

Data type: `Boolean`

If true, then /etc/httpd/conf.d/ipa.conf is written to exclude kerberos support for incoming

Default value: `false`

##### `webui_enable_proxy`

Data type: `Boolean`

If true, then httpd is configured to act as a reverse proxy for the IPA Web UI. This allows

Default value: `false`

##### `webui_force_https`

Data type: `Boolean`

If true, then /etc/httpd/conf.d/ipa-rewrite.conf is modified to force all connections to https.

Default value: `false`

##### `webui_proxy_external_fqdn`

Data type: `Stdlib::Fqdn`

The public or external FQDN used to access the IPA Web UI behind the reverse proxy.

Default value: 'localhost'

##### `webui_proxy_https_port`

Data type: `String`

The HTTPS port to use for the reverse proxy. Cannot be 443.

Default value: '8440'

### freeipa::config::admin_user

Configures admin user

#### Examples

##### 

```puppet
include freeipa::config::admin_user
```

### freeipa::config::webui

Configures port and redirect overrides for the IPA server web UI.

#### Examples

##### 

```puppet
include freeipa::config::webui
```

### freeipa::install

Installs the packages needed for servers and clients

#### Examples

##### 

```puppet
include freeipa::install
```

### freeipa::install::autofs

Installs and start autofs

#### Examples

##### 

```puppet
include freeipa::install::autofs
```

### freeipa::install::client

Install freeipa client

#### Examples

##### 

```puppet
include freeipa::install::client
```

### freeipa::install::server

This class mainly defines options for the ipa install command, then install master or replica regarding the role set.

#### Examples

##### 

```puppet
include freeipa::install::server
```

### freeipa::install::server::master

Installs freeipa server as master

#### Examples

##### 

```puppet
include freeipa::install::server::master
```

### freeipa::install::server::replica

Installs freeipa server as replica

#### Examples

##### 

```puppet
include freeipa::install::server::replica
```

### freeipa::install::sssd

Install sssd package

#### Examples

##### 

```puppet
include freeipa::install::sssd
```

## Defined types

### freeipa::helpers::flushcache

Flushcache sss for Debian and RedHat only

#### Examples

##### 

```puppet
freeipa::helpers::flushcache { 'namevar': }
```

